==> opensubdiv-3.0.2-3-aarch64.pkg.tar.xz: usr/share/doc/opensubdiv/doxy_html/search/functions_e.js <==
var searchData=
[
  ['reclassifysemisharpvalues',['reclassifySemisharpValues',['../a00036.html#abbf402689bd1d85f79a188a0bc2ad403',1,'OpenSubdiv::OPENSUBDIV_VERSION::Vtr::internal::FVarRefinement']]],
  ['reclassifysemisharpvertices',['reclassifySemisharpVertices',['../a00073.html#a0e8c554524ea994645705850b43d91f3',1,'OpenSubdiv::OPENSUBDIV_VERSION::Vtr::internal::Refinement']]],
  ['refine',['refine',['../a00073.html#a865ced39fac8b7f63f48bbf06871705c',1,'OpenSubdiv::OPENSUBDIV_VERSION::Vtr::internal::Refinement::refine()'],['../a00053.html#a9a90398ba2073fe3da454f6b00deb33c',1,'OpenSubdiv::OPENSUBDIV_VERSION::Osd::MeshInterface::Refine()'],['../a00052.html#a32c8d641fe9ea1565be646a10c5d6c85',1,'OpenSubdiv::OPENSUBDIV_VERSION::Osd::Mesh::Refine()']]],
  ['refineadaptive',['RefineAdaptive',['../a00086.html#adc05db2d92b02e349e1c305cd9ef5361',1,'OpenSubdiv::OPENSUBDIV_VERSION::Far::TopologyRefiner']]],
  ['refinement',['Refinement',['../a00073.html#a8915a7ba70ebf426a3a714cf24a438ba',1,'OpenSubdiv::OPENSUBDIV_VERSION::Vtr::internal::Refinement']]],
  ['refinemesh',['refineMesh',['../a00053.html#a51f237c3f08f6ddc2ea7ba5cb0d00b36',1,'OpenSubdiv::OPENSUBDIV_VERSION::Osd::MeshInterface']]],
  ['refineuniform',['RefineUniform',['../a00086.html#ad22b7ffd9f8f3b488e5f220cf00c8c82',1,'OpenSubdiv::OPENSUBDIV_VERSION::Far::TopologyRefiner']]],
  ['reportinvalidtopology',['reportInvalidTopology',['../a00087.html#a0c4c1d44df4c480bd0adfa9e86891b39',1,'OpenSubdiv::OPENSUBDIV_VERSION::Far::TopologyRefinerFactory']]],
  ['reserve',['Reserve',['../a00079.html#ad0f6d2b8e7314737ee5cad42bf4928c5',1,'OpenSubdiv::OPENSUBDIV_VERSION::Vtr::internal::StackBuffer']]],
  ['reset',['Reset',['../a00003.html#a372de693ad40b3f42839c8ec6ac845f4',1,'OpenSubdiv::OPENSUBDIV_VERSION::Osd::BufferDescriptor']]],
  ['resize',['resize',['../a00081.html#ac21f18df5c8da2db4d23287cdab5fcc1',1,'OpenSubdiv::OPENSUBDIV_VERSION::Far::StencilTable']]],
  ['resizecomponents',['resizeComponents',['../a00035.html#a96ffc057821d4292e5a9946baa512a35',1,'OpenSubdiv::OPENSUBDIV_VERSION::Vtr::internal::FVarLevel']]],
  ['resizecomponenttopology',['resizeComponentTopology',['../a00087.html#a4c574c458d080393a258f48e0ab20938',1,'OpenSubdiv::OPENSUBDIV_VERSION::Far::TopologyRefinerFactory']]],
  ['resizeedgefaces',['resizeEdgeFaces',['../a00046.html#a01ef61aac46ff37d15c664c0a39b04da',1,'OpenSubdiv::OPENSUBDIV_VERSION::Vtr::internal::Level::resizeEdgeFaces(int numEdgeFacesTotal)'],['../a00046.html#a94010a718ea8242a44d0ad5c0ace27e7',1,'OpenSubdiv::OPENSUBDIV_VERSION::Vtr::internal::Level::resizeEdgeFaces(Index edgeIndex, int count)']]],
  ['resizeedges',['resizeEdges',['../a00046.html#a0f01eb30c2601d052c920d730b1d9cf2',1,'OpenSubdiv::OPENSUBDIV_VERSION::Vtr::internal::Level']]],
  ['resizeedgevertices',['resizeEdgeVertices',['../a00046.html#add2d4ee64cde5aa42147275e592075ff',1,'OpenSubdiv::OPENSUBDIV_VERSION::Vtr::internal::Level']]],
  ['resizefaceedges',['resizeFaceEdges',['../a00046.html#a3b9682483ab40cb10451b72b4526b99d',1,'OpenSubdiv::OPENSUBDIV_VERSION::Vtr::internal::Level']]],
  ['resizefaces',['resizeFaces',['../a00046.html#a538adf81251e367e61330a8818aca4c4',1,'OpenSubdiv::OPENSUBDIV_VERSION::Vtr::internal::Level']]],
  ['resizefacevertices',['resizeFaceVertices',['../a00046.html#a44926850dfa7dfcf9e941d01562bc69b',1,'OpenSubdiv::OPENSUBDIV_VERSION::Vtr::internal::Level::resizeFaceVertices(int numFaceVertsTotal)'],['../a00046.html#ae6c9e376724cc42ee77e98320ec83cb9',1,'OpenSubdiv::OPENSUBDIV_VERSION::Vtr::internal::Level::resizeFaceVertices(Index FaceIndex, int count)']]],
  ['resizevalues',['resizeValues',['../a00035.html#a5c1587a355b43bf4b375cc72ea897dc5',1,'OpenSubdiv::OPENSUBDIV_VERSION::Vtr::internal::FVarLevel']]],
  ['resizevertexedges',['resizeVertexEdges',['../a00046.html#aa42fb1c3dfdcf07fdec2599717d21e12',1,'OpenSubdiv::OPENSUBDIV_VERSION::Vtr::internal::Level::resizeVertexEdges(int numVertexEdgesTotal)'],['../a00046.html#a2574d5af455c512d3955ef73a022c293',1,'OpenSubdiv::OPENSUBDIV_VERSION::Vtr::internal::Level::resizeVertexEdges(Index vertIndex, int count)']]],
  ['resizevertexfaces',['resizeVertexFaces',['../a00046.html#ab95413a9322bb3a0a2c13b4555f5aed3',1,'OpenSubdiv::OPENSUBDIV_VERSION::Vtr::internal::Level::resizeVertexFaces(int numVertexFacesTotal)'],['../a00046.html#a1aca583c5320dd040175db33e7e1028c',1,'OpenSubdiv::OPENSUBDIV_VERSION::Vtr::internal::Level::resizeVertexFaces(Index vertIndex, int count)']]],
  ['resizevertexvalues',['resizeVertexValues',['../a00035.html#a0c1cf20d03ea2564de71e0921d8d0412',1,'OpenSubdiv::OPENSUBDIV_VERSION::Vtr::internal::FVarLevel']]],
  ['resizevertices',['resizeVertices',['../a00046.html#a8410d3356c5ed956d71756628642ecd4',1,'OpenSubdiv::OPENSUBDIV_VERSION::Vtr::internal::Level']]]
];

==> opensubdiv-3.0.5-1-aarch64.pkg.tar.xz: usr/share/doc/opensubdiv/doxy_html/search/functions_e.js <==
var searchData=
[
  ['reclassifysemisharpvalues',['reclassifySemisharpValues',['../a00036.html#abbf402689bd1d85f79a188a0bc2ad403',1,'OpenSubdiv::OPENSUBDIV_VERSION::Vtr::internal::FVarRefinement']]],
  ['reclassifysemisharpvertices',['reclassifySemisharpVertices',['../a00073.html#a0e8c554524ea994645705850b43d91f3',1,'OpenSubdiv::OPENSUBDIV_VERSION::Vtr::internal::Refinement']]],
  ['refine',['refine',['../a00073.html#a865ced39fac8b7f63f48bbf06871705c',1,'OpenSubdiv::OPENSUBDIV_VERSION::Vtr::internal::Refinement::refine()'],['../a00053.html#a9a90398ba2073fe3da454f6b00deb33c',1,'OpenSubdiv::OPENSUBDIV_VERSION::Osd::MeshInterface::Refine()'],['../a00052.html#a32c8d641fe9ea1565be646a10c5d6c85',1,'OpenSubdiv::OPENSUBDIV_VERSION::Osd::Mesh::Refine()']]],
  ['refineadaptive',['RefineAdaptive',['../a00086.html#adc05db2d92b02e349e1c305cd9ef5361',1,'OpenSubdiv::OPENSUBDIV_VERSION::Far::TopologyRefiner']]],
  ['refinement',['Refinement',['../a00073.html#a8915a7ba70ebf426a3a714cf24a438ba',1,'OpenSubdiv::OPENSUBDIV_VERSION::Vtr::internal::Refinement']]],
  ['refinemesh',['refineMesh',['../a00053.html#a51f237c3f08f6ddc2ea7ba5cb0d00b36',1,'OpenSubdiv::OPENSUBDIV_VERSION::Osd::MeshInterface']]],
  ['refineuniform',['RefineUniform',['../a00086.html#ad22b7ffd9f8f3b488e5f220cf00c8c82',1,'OpenSubdiv::OPENSUBDIV_VERSION::Far::TopologyRefiner']]],
  ['reportinvalidtopology',['reportInvalidTopology',['../a00087.html#a0c4c1d44df4c480bd0adfa9e86891b39',1,'OpenSubdiv::OPENSUBDIV_VERSION::Far::TopologyRefinerFactory']]],
  ['reserve',['Reserve',['../a00079.html#ad0f6d2b8e7314737ee5cad42bf4928c5',1,'OpenSubdiv::OPENSUBDIV_VERSION::Vtr::internal::StackBuffer::Reserve()'],['../a00081.html#ae00a9e01294323589df33d2680dab235',1,'OpenSubdiv::OPENSUBDIV_VERSION::Far::StencilTable::reserve()']]],
  ['reset',['Reset',['../a00003.html#a372de693ad40b3f42839c8ec6ac845f4',1,'OpenSubdiv::OPENSUBDIV_VERSION::Osd::BufferDescriptor']]],
  ['resize',['resize',['../a00081.html#ac21f18df5c8da2db4d23287cdab5fcc1',1,'OpenSubdiv::OPENSUBDIV_VERSION::Far::StencilTable']]],
  ['resizecomponents',['resizeComponents',['../a00035.html#a96ffc057821d4292e5a9946baa512a35',1,'OpenSubdiv::OPENSUBDIV_VERSION::Vtr::internal::FVarLevel']]],
  ['resizecomponenttopology',['resizeComponentTopology',['../a00087.html#a4c574c458d080393a258f48e0ab20938',1,'OpenSubdiv::OPENSUBDIV_VERSION::Far::TopologyRefinerFactory']]],
  ['resizeedgefaces',['resizeEdgeFaces',['../a00046.html#a01ef61aac46ff37d15c664c0a39b04da',1,'OpenSubdiv::OPENSUBDIV_VERSION::Vtr::internal::Level::resizeEdgeFaces(int numEdgeFacesTotal)'],['../a00046.html#a94010a718ea8242a44d0ad5c0ace27e7',1,'OpenSubdiv::OPENSUBDIV_VERSION::Vtr::internal::Level::resizeEdgeFaces(Index edgeIndex, int count)']]],
  ['resizeedges',['resizeEdges',['../a00046.html#a0f01eb30c2601d052c920d730b1d9cf2',1,'OpenSubdiv::OPENSUBDIV_VERSION::Vtr::internal::Level']]],
  ['resizeedgevertices',['resizeEdgeVertices',['../a00046.html#add2d4ee64cde5aa42147275e592075ff',1,'OpenSubdiv::OPENSUBDIV_VERSION::Vtr::internal::Level']]],
  ['resizefaceedges',['resizeFaceEdges',['../a00046.html#a3b9682483ab40cb10451b72b4526b99d',1,'OpenSubdiv::OPENSUBDIV_VERSION::Vtr::internal::Level']]],
  ['resizefaces',['resizeFaces',['../a00046.html#a538adf81251e367e61330a8818aca4c4',1,'OpenSubdiv::OPENSUBDIV_VERSION::Vtr::internal::Level']]],
  ['resizefacevertices',['resizeFaceVertices',['../a00046.html#a44926850dfa7dfcf9e941d01562bc69b',1,'OpenSubdiv::OPENSUBDIV_VERSION::Vtr::internal::Level::resizeFaceVertices(int numFaceVertsTotal)'],['../a00046.html#ae6c9e376724cc42ee77e98320ec83cb9',1,'OpenSubdiv::OPENSUBDIV_VERSION::Vtr::internal::Level::resizeFaceVertices(Index FaceIndex, int count)']]],
  ['resizevalues',['resizeValues',['../a00035.html#a5c1587a355b43bf4b375cc72ea897dc5',1,'OpenSubdiv::OPENSUBDIV_VERSION::Vtr::internal::FVarLevel']]],
  ['resizevertexedges',['resizeVertexEdges',['../a00046.html#aa42fb1c3dfdcf07fdec2599717d21e12',1,'OpenSubdiv::OPENSUBDIV_VERSION::Vtr::internal::Level::resizeVertexEdges(int numVertexEdgesTotal)'],['../a00046.html#a2574d5af455c512d3955ef73a022c293',1,'OpenSubdiv::OPENSUBDIV_VERSION::Vtr::internal::Level::resizeVertexEdges(Index vertIndex, int count)']]],
  ['resizevertexfaces',['resizeVertexFaces',['../a00046.html#ab95413a9322bb3a0a2c13b4555f5aed3',1,'OpenSubdiv::OPENSUBDIV_VERSION::Vtr::internal::Level::resizeVertexFaces(int numVertexFacesTotal)'],['../a00046.html#a1aca583c5320dd040175db33e7e1028c',1,'OpenSubdiv::OPENSUBDIV_VERSION::Vtr::internal::Level::resizeVertexFaces(Index vertIndex, int count)']]],
  ['resizevertexvalues',['resizeVertexValues',['../a00035.html#a0c1cf20d03ea2564de71e0921d8d0412',1,'OpenSubdiv::OPENSUBDIV_VERSION::Vtr::internal::FVarLevel']]],
  ['resizevertices',['resizeVertices',['../a00046.html#a8410d3356c5ed956d71756628642ecd4',1,'OpenSubdiv::OPENSUBDIV_VERSION::Vtr::internal::Level']]]
];
